@@ -8,9 +8,8 @@ from json import load as _load, dump as _dump
 import ipaddress as _ipaddress
 from datetime import datetime as _datetime
 
-from creole.loader import creole_loader as _creole_loader
 from tiramisu.option import DomainnameOption as _DomainnameOption
-from time import time
+from creole.loader import creole_loader as _creole_loader
 
 _CONFIG_FILE = '/var/lib/eole/config/eoledhcp.cfg'
 
@@ -204,7 +203,8 @@ def _get_config(name):
         return cfg.get('eole', 'dhcp_path')
 
 
-_LEASES_DATABASE = '/var/lib/dhcp/dhcpd.leases'
+_LEASES_DATABASE = _get_config("LEASES_FILE")
+
 _DHCP_LEASES_ATTRS = {
         'ends': _re.compile(r'^\s*ends\s+(?P<value>.*);', _re.M),
         'binding state': _re.compile(r'^\s*binding state\s+(?P<value>.*);', _re.M),
@@ -288,10 +288,13 @@ def get_leases(*args, **kwargs):
 
 def _get_free_ip(is_dynamic, total, leases, first, last):
     if is_dynamic: #free leases is the difference between total ip and active leases
+        free_leases = []
         for idx, lease in enumerate(leases):
             if first <= lease <= last:
                 total -= 1
-                del leases[idx]
+            else:
+                free_leases.append(leases[idx])
+        leases = free_leases
         return total
 
 def _get_subnets(cfg):
